==> codacy-plugins_2.12-8.9.2_play_2.6.jar: tool-cache/codacy-sonar-csharp/docs/description/S4457.md <==

Because of the way `async/await` methods are rewritten by the compiler, any exceptions thrown during the parameters check will happen<br>only when the task is observed. That could happen far away from the source of the buggy code or never happen for fire-and-forget tasks.

Therefore it is recommended to split the method into two: an outer method handling the parameter checks (without being `async/await`)<br>and an inner method to handle the iterator block with the `async/await` pattern.

This rule raises an issue when an `async` method throws any exception derived from `ArgumentException` and contains<br>`await` keyword.

## Noncompliant Code Example


    public static async Task SkipLinesAsync(this TextReader reader, int linesToSkip) // Noncompliant
    {
        if (reader == null) { throw new ArgumentNullException(nameof(reader)); }
        if (linesToSkip &lt; 0) { throw new ArgumentOutOfRangeException(nameof(linesToSkip)); }
    
        for (var i = 0; i &lt; linesToSkip; ++i)
        {
            var line = await reader.ReadLineAsync().ConfigureAwait(false);
            if (line == null) { break; }
        }
    }


## Compliant Solution


    public static Task SkipLinesAsync(this TextReader reader, int linesToSkip)
    {
        if (reader == null) { throw new ArgumentNullException(nameof(reader)); }
        if (linesToSkip &lt; 0) { throw new ArgumentOutOfRangeException(nameof(linesToSkip)); }
    
        return reader.SkipLinesInternalAsync(linesToSkip);
    }
    
    private static async Task SkipLinesInternalAsync(this TextReader reader, int linesToSkip)
    {
        for (var i = 0; i &lt; linesToSkip; ++i)
        {
            var line = await reader.ReadLineAsync().ConfigureAwait(false);
            if (line == null) { break; }
        }
    }

==> codacy-plugins_2.12-11.0.1_play_2.6.jar: tool-cache/codacy-sonar-csharp/docs/description/S4457.md <==

Because of the way `async/await` methods are rewritten by the compiler, any exceptions thrown during the parameters check will happen only when the task is observed. That could happen far away from the source of the buggy code or never happen for fire-and-forget tasks.

Therefore it is recommended to split the method into two: an outer method handling the parameter checks (without being `async/await`) and an inner method to handle the iterator block with the `async/await` pattern.

This rule raises an issue when an `async` method throws any exception derived from `ArgumentException` and contains `await` keyword.

## Noncompliant Code Example


    public static async Task SkipLinesAsync(this TextReader reader, int linesToSkip) // Noncompliant
    {
        if (reader == null) { throw new ArgumentNullException(nameof(reader)); }
        if (linesToSkip &lt; 0) { throw new ArgumentOutOfRangeException(nameof(linesToSkip)); }
    
        for (var i = 0; i &lt; linesToSkip; ++i)
        {
            var line = await reader.ReadLineAsync().ConfigureAwait(false);
            if (line == null) { break; }
        }
    }


## Compliant Solution


    public static Task SkipLinesAsync(this TextReader reader, int linesToSkip)
    {
        if (reader == null) { throw new ArgumentNullException(nameof(reader)); }
        if (linesToSkip &lt; 0) { throw new ArgumentOutOfRangeException(nameof(linesToSkip)); }
    
        return reader.SkipLinesInternalAsync(linesToSkip);
    }
    
    private static async Task SkipLinesInternalAsync(this TextReader reader, int linesToSkip)
    {
        for (var i = 0; i &lt; linesToSkip; ++i)
        {
            var line = await reader.ReadLineAsync().ConfigureAwait(false);
            if (line == null) { break; }
        }
    }
